package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERGeneralizedTime;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;

public class RecipientKeyIdentifier extends ASN1Encodable {
   private ASN1OctetString subjectKeyIdentifier;
   private DERGeneralizedTime date;
   private OtherKeyAttribute other;

   public RecipientKeyIdentifier(ASN1OctetString subjectKeyIdentifier, DERGeneralizedTime date, OtherKeyAttribute other) {
      this.subjectKeyIdentifier = subjectKeyIdentifier;
      this.date = date;
      this.other = other;
   }

   public RecipientKeyIdentifier(ASN1Sequence seq) {
      this.subjectKeyIdentifier = ASN1OctetString.getInstance(seq.getObjectAt(0));
      int var2;
      if ((var2 = seq.size()) != 1) {
         if (var2 != 2) {
            if (var2 != 3) {
               throw new IllegalArgumentException("Invalid KEKIdentifier");
            }

            this.date = (DERGeneralizedTime)seq.getObjectAt(1);
            this.other = OtherKeyAttribute.getInstance(seq.getObjectAt(2));
         } else if (seq.getObjectAt(1) instanceof DERGeneralizedTime) {
            this.date = (DERGeneralizedTime)seq.getObjectAt(1);
         } else {
            this.other = OtherKeyAttribute.getInstance(seq.getObjectAt(2));
         }
      }

   }

   public static RecipientKeyIdentifier getInstance(ASN1TaggedObject _ato, boolean _explicit) {
      return getInstance(ASN1Sequence.getInstance(_ato, _explicit));
   }

   public static RecipientKeyIdentifier getInstance(Object _obj) {
      if (_obj != null && !(_obj instanceof RecipientKeyIdentifier)) {
         if (_obj instanceof ASN1Sequence) {
            return new RecipientKeyIdentifier((ASN1Sequence)_obj);
         } else {
            throw new IllegalArgumentException("Invalid RecipientKeyIdentifier: " + _obj.getClass().getName());
         }
      } else {
         return (RecipientKeyIdentifier)_obj;
      }
   }

   public ASN1OctetString getSubjectKeyIdentifier() {
      return this.subjectKeyIdentifier;
   }

   public DERGeneralizedTime getDate() {
      return this.date;
   }

   public OtherKeyAttribute getOtherKeyAttribute() {
      return this.other;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.subjectKeyIdentifier);
      DERGeneralizedTime var2;
      if ((var2 = this.date) != null) {
         var1.add(var2);
      }

      OtherKeyAttribute var3;
      if ((var3 = this.other) != null) {
         var1.add(var3);
      }

      return new DERSequence(var1);
   }
}
